==> dde-shell_1.99.36.tar.xz: BUILD/panels/notification/osd/default/translations/org.deepin.ds.osd.default_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>main</name>
    <message>
        <source>WLAN on</source>
        <translation>Wifi activé</translation>
    </message>
    <message>
        <source>WLAN off</source>
        <translation>Wifi désactivé</translation>
    </message>
    <message>
        <source>Caps Lock on</source>
        <translation>Verrouillage majuscules activé</translation>
    </message>
    <message>
        <source>Caps Lock off</source>
        <translation>Verrouillage majuscules désactivé</translation>
    </message>
    <message>
        <source>Numeric keypad on</source>
        <translation>Pavé numérique activé</translation>
    </message>
    <message>
        <source>Numeric keypad off</source>
        <translation>Pavé numérique désactivé</translation>
    </message>
    <message>
        <source>Touchpad on</source>
        <translation>Pavé tactile activé</translation>
    </message>
    <message>
        <source>Touchpad off</source>
        <translation>Pavé tactile désactivé</translation>
    </message>
    <message>
        <source>Touchpad toggle</source>
        <translation>Basculer le pavé tactile</translation>
    </message>
    <message>
        <source>Fn toggle</source>
        <translation>Basculer les touches Fn</translation>
    </message>
    <message>
        <source>Airplane mode on</source>
        <translation>Mode avion activé</translation>
    </message>
    <message>
        <source>Airplane mode off</source>
        <translation>Mode avion désactivé</translation>
    </message>
    <message>
        <source>Mute on</source>
        <translation>Sourdine activée</translation>
    </message>
    <message>
        <source>Mute off</source>
        <translation>Sourdine désactivée</translation>
    </message>
    <message>
        <source>Balanced power</source>
        <translation>Mode d&apos;énergie équilibré</translation>
    </message>
    <message>
        <source>Power saver</source>
        <translation>Mode d&apos;économie d&apos;énergie</translation>
    </message>
    <message>
        <source>High performance</source>
        <translation>Mode haute performance</translation>
    </message>
    <message>
        <source>Window effect enabled</source>
        <translation>Effets de fenêtres activés</translation>
    </message>
    <message>
        <source>Window effect disabled</source>
        <translation>Effets de fenêtres désactivés</translation>
    </message>
    <message>
        <source>Failed to enable window effects</source>
        <translation>Impossible d&apos;activer les effets de fenêtres</translation>
    </message>
</context>
</TS>

==> dde-shell_2.0.3.tar.xz: BUILD/panels/notification/osd/default/translations/org.deepin.ds.osd.default_fr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fr">
<context>
    <name>main</name>
    <message>
        <source>WLAN on</source>
        <translation>Wifi activé</translation>
    </message>
    <message>
        <source>WLAN off</source>
        <translation>Wifi désactivé</translation>
    </message>
    <message>
        <source>Caps Lock on</source>
        <translation>Verrouillage majuscules activé</translation>
    </message>
    <message>
        <source>Caps Lock off</source>
        <translation>Verrouillage majuscules désactivé</translation>
    </message>
    <message>
        <source>Numeric keypad on</source>
        <translation>Pavé numérique activé</translation>
    </message>
    <message>
        <source>Numeric keypad off</source>
        <translation>Pavé numérique désactivé</translation>
    </message>
    <message>
        <source>Touchpad on</source>
        <translation>Pavé tactile activé</translation>
    </message>
    <message>
        <source>Touchpad off</source>
        <translation>Pavé tactile désactivé</translation>
    </message>
    <message>
        <source>Touchpad toggle</source>
        <translation>Basculer le pavé tactile</translation>
    </message>
    <message>
        <source>Fn toggle</source>
        <translation>Basculer les touches Fn</translation>
    </message>
    <message>
        <source>Airplane mode on</source>
        <translation>Mode avion activé</translation>
    </message>
    <message>
        <source>Airplane mode off</source>
        <translation>Mode avion désactivé</translation>
    </message>
    <message>
        <source>Mute on</source>
        <translation>Sourdine activée</translation>
    </message>
    <message>
        <source>Mute off</source>
        <translation>Sourdine désactivée</translation>
    </message>
    <message>
        <source>Balanced power</source>
        <translation>Mode d&apos;énergie équilibré</translation>
    </message>
    <message>
        <source>Power saver</source>
        <translation>Mode d&apos;économie d&apos;énergie</translation>
    </message>
    <message>
        <source>High performance</source>
        <translation>Mode haute performance</translation>
    </message>
    <message>
        <source>Window effect enabled</source>
        <translation>Effets de fenêtres activés</translation>
    </message>
    <message>
        <source>Window effect disabled</source>
        <translation>Effets de fenêtres désactivés</translation>
    </message>
    <message>
        <source>Failed to enable window effects</source>
        <translation>Impossible d&apos;activer les effets de fenêtres</translation>
    </message>
</context>
</TS>
